@@ -1,16 +1,42 @@
-class GenomicPosition(object):
+from functools import total_ordering
+from lhc.order import natural_key
 
-    def __init__(self, chromosome, position, strand='+'):
-        self.chromosome = chromosome
-        self.position = position
-        self.strand = strand
+
+class ChromosomeIdentifier:
+    def __init__(self, parts):
+        self.parts = tuple(parts)
 
     def __str__(self):
-        return '{}:{}'.format(self.chromosome, self.position + 1)
+        return ''.join(str(part) for part in self.parts)
+
+    def __hash__(self):
+        return hash(self.parts)
+
+    def __eq__(self, other):
+        return self.parts == other.parts
+
+    def __lt__(self, other):
+        return self.parts < other.parts
+
+
+@total_ordering
+class GenomicPosition:
+
+    def __init__(self, chromosome, position, *, strand='+', data=None):
+        self.chromosome = chromosome if isinstance(chromosome, ChromosomeIdentifier) else ChromosomeIdentifier(natural_key(chromosome))
+        self.position = position
+        self.strand = strand
+        self.data = data
+
+    def __str__(self):
+        return '{}:{}:{}'.format(self.chromosome, self.strand, self.position + 1)
 
     def __repr__(self):
         return 'GenomicPosition({})'.format(self)
 
+    def __hash__(self):
+        return hash((self.chromosome, self.position))
+
     def __eq__(self, other):
         return self.chromosome == other.chromosome and self.position == other.position and\
             self.strand == other.strand
@@ -30,17 +56,19 @@ class GenomicPosition(object):
 
     def __sub__(self, other):
         """
-        Subtract either an integer from the current position or find the distance between two positions
+        Subtract either an integer from the current position
         :param int other: integer to subtract
         :return: new position
         :rtype: GenomicPosition
         """
+        if isinstance(other, GenomicPosition):
+            return self.get_distance_to(other)
         return GenomicPosition(self.chromosome, self.position - other, strand=self.strand)
 
     def get_distance_to(self, other):
         """
         Get the distance between two positions
-        :param other: other position
+        :param GenomicPosition other: other position
         :return: distance between positions
         :rtype: int
         """
